@@ -2,10 +2,10 @@ import ctre
 import math
 
 from robotpy_toolkit_7407.utils.units import radians
-from robotpy_toolkit_7407.sensors.gyro.base_gyro import Gyro
+from robotpy_toolkit_7407.sensors.gyro.base_gyro import BaseGyro
 
 
-class PigeonIMUGyro_Wrapper(Gyro):
+class PigeonIMUGyro_Wrapper(BaseGyro):
     """
     Wrapper class for the Pigeon2 IMU gyro.
     """
@@ -31,9 +31,23 @@ class PigeonIMUGyro_Wrapper(Gyro):
         """
         return math.radians(self._gyro.getYaw())
 
+    def get_robot_pitch(self) -> radians:
+        """
+        Returns the angle of the robot's pitch in radians
+        :return: Robot pitch (radians)
+        """
+        return math.radians(self._gyro.getPitch())
+
+    def get_robot_roll(self) -> radians:
+        """
+        Returns the angle of the robot's roll in radians
+        :return: Robot roll (radians)
+        """
+        return math.radians(self._gyro.getRoll())
+
     # reset the gyro
-    def reset_angle(self, angle=0):
+    def reset_angle(self, angle: radians = 0):
         """
         Resets the gyro's yaw.
         """
-        self._gyro.setYaw(angle)
+        self._gyro.setYaw(math.degrees(angle))
