@@ -13,7 +13,7 @@ class VisionEstimator:
     def get_estimated_robot_pose(self) -> list[Pose3d, float] | None:
         """
         Returns the robot's pose relative to the field, estimated by the vision system. Override this method.
-        :return: Vision system estimate of robot pose.
+        :return: Vision system estimate of robot pose along with the associated timestamp.
         :rtype: list[Pose3d, seconds: float] | None
         """
         raise NotImplementedError
